@@ -3,14 +3,14 @@
 # This code is released under the Artistic License.
 #
 # XML::RAI::Object - A base class for RAI element objects.
-# 
+#
 
 package XML::RAI::Object;
 
 use strict;
 
 use Date::Parse 2.26;
-use Date::Format;
+use Date::Format 2.22;
 
 sub new {
     my $class = shift;
@@ -22,23 +22,36 @@ sub new {
 sub init {
     $_[0]->{__source} = $_[1];
     $_[0]->{__parent} = $_[2];
-    $_[0]->{__RAI} = $_[2];
-    while ($_[0]->{__RAI}->can('parent')) { 
-        $_[0]->{__RAI} = $_[0]->{__RAI}->parent 
+    $_[0]->{__RAI}    = $_[2];
+    while ($_[0]->{__RAI}->can('parent')) {
+        $_[0]->{__RAI} = $_[0]->{__RAI}->parent;
     }
 }
 
-sub src { $_[0]->{__source} }
+sub src    { $_[0]->{__source} }
 sub parent { $_[0]->{__parent} }
 
-sub generic_handler {
-    my ($this,$class,$var) = @_;
+sub add_mapping {
+    my ($class, $var, @maps) = @_;
     no strict 'refs';
-    foreach (@{${$class.'::XMap'}->{$var}}) { 
+    ${"${class}::XMap"}->{$var} = []
+      unless (exists ${"${class}::XMap"}->{$var});
+    push @{${"${class}::XMap"}->{$var}}, @maps;
+}
+
+sub generic_handler {
+    my ($this, $class, $var) = @_;
+    no strict 'refs';
+    foreach (@{${$class . '::XMap'}->{$var}}) {
         my @nodes = $this->src->query($_);
-        if (defined($nodes[0])) { 
-            @nodes = map{ ref($_) ? $_->text_content : $_ } @nodes;
-            return wantarray ? @nodes : $nodes[0]; 
+        if (defined($nodes[0])) {
+            @nodes = map {
+                !ref($_) ? $_
+                  : substr($_->name, 0, 30) eq '{http://www.w3.org/1999/xhtml}'
+                  ? join '', map { as_xhtml($_) } @{$_->contents}
+                  : $_->text_content;
+            } @nodes;
+            return wantarray ? @nodes : $nodes[0];
         }
     }
     return undef;
@@ -48,33 +61,36 @@ sub time_handler {
     my @r = generic_handler(@_);
     return undef unless $r[0];
     my $timef = $_[0]->{__RAI}->time_format;
-    if ($timef eq 'EPOCH') { 
-        map { $_ = str2time($_,0) } @r
+    if ($timef eq 'EPOCH') {
+        map { $_ = str2time($_, 0) } @r;
     } elsif ($timef) {
-        map { 
-            my @time = localtime(str2time($_,0)); 
-            $_ = strftime( $timef, @time, 0);
-        } @r 
-    } 
-    #else { # PASS-THRU
-    #    map { $_ = $_->text_content } @r
-    #}
+        map { $_ = time2str($timef, str2time($_, 0), 0) } @r;
+    }
     wantarray ? @r : $r[0];
 }
 
+use XML::RSS::Parser::Util qw(as_xml);
+
+sub as_xhtml {    # a hack to get xhtml content as we'd expect.
+    my $xml = as_xml($_[0]);
+    $xml =~ s{<(/?)xhtml:}{<$1}g;
+    $xml;
+}
+
 sub DESTROY { }
 
 use vars qw( $AUTOLOAD );
+
 sub AUTOLOAD {
-    (my $var = $AUTOLOAD) =~ s!.+::!!;
+    (my $var   = $AUTOLOAD) =~ s!.+::!!;
     (my $class = $AUTOLOAD) =~ s!::[^:]+$!!;
     no strict 'refs';
     die "$var is not a recognized method."
-        unless (${$class.'::XMap'}->{$var});
-    if ($var=~m/^(created|modified|issued|valid)$/) {
-        *$AUTOLOAD = sub { time_handler($_[0],$class,$var) }; 
+      unless (${$class . '::XMap'}->{$var});
+    if ($var =~ m/^(created|modified|issued|valid)(_strict)?$/) {
+        *$AUTOLOAD = sub { time_handler($_[0], $class, $var) };
     } else {
-        *$AUTOLOAD = sub { generic_handler($_[0],$class,$var) };
+        *$AUTOLOAD = sub { generic_handler($_[0], $class, $var) };
     }
     goto &$AUTOLOAD;
 }
@@ -103,4 +119,4 @@ information.
 
 =cut
 
-=end
\ No newline at end of file
+=end
